Calculate costs for a specific combinations of lambda, muVec and sigmaVec.
calculateCostHist(
lambda,
muVec,
sigmaVec,
HistData,
alpha = 0.01,
alphaMcb = 0.1,
pNormLookup
)(numeric) vector with (lambda, mu, sigma, P, cost).
(numeric) transformation parameter for inverse Box-Cox transformation
(numeric) vector of mean values of non-pathological Gaussian distribution in transformed space
(numeric) vector of sd values of non-pathological Gaussian distribution in transformed space
(list) with histogram data generated by function generateHistData
(numeric) specifying the confidence region used for selection of histgram bins in cost calculation
(numeric) specifying the confidence level defining the maximal allowed counts below asymmetric confidence region
(list) with lookup table for pnormApprox function pnormApprox
Tatjana Ammer tatjana.ammer@roche.com