Learn R Programming

refineR (version 2.0.0)

perc_ci_asymptotic: Function to approximate the sampling uncertainty of quantiles using the asymptotic method

Description

Function to approximate the sampling uncertainty of quantiles using the asymptotic method

Usage

perc_ci_asymptotic(mu, sigma, n, prob, conf.level)

Value

(matrix) of confidence interval(s) of quantiles of the normal distribution

Arguments

mu

(numeric) mean of the distribution

sigma

(numeric) standard deviation of the distribution

n

(numeric) integer value indicating the sample size

prob

(numeric) quantile value(s) for which to calculate the confidence interval(s)

conf.level

(numeric) confidence level for the interval(s)

Author

Florian Dufey florian.dufey@roche.com

References

Serfling RJ. Approximation theorems of mathematical statistics. NY: John Wiley & Sons; 1980:121 p.

Examples

Run this code
if (FALSE) {
perc_ci_asymptotic(mu = 0, sigma = 1, n = 120, prob = c(0.025, 0.975), conf.level = 0.9)
}

Run the code above in your browser using DataLab