findPeaksAndValleys: Find the index of the peaks and valleys of the density estimation.
Description
Find the index of the peaks and valleys of the density estimation.
Usage
findPeaksAndValleys(Dens)
Value
(list) specifying the index of the peaks and valleys of the density estimation.
Arguments
- Dens
(list) with density estimation (x values, y values)